biom.table.Table.length — biom-format.org

# biom-format.org

## biom.table.Table.length

`Table.` `length`(axis='sample')

  Return the length of an axis

  Parameters: | axis : {‘sample’, ‘observation’}, optional The axis to operate on
  Raises: | UnknownAxisError If provided an unrecognized axis.

  Examples

      >>> from biom import example_table
      >>> print example_table.length(axis='sample')
      3
      >>> print example_table.length(axis='observation')
      2